@@ -228,11 +228,10 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
 	VALUE_PAIR *namepair,
 	char *pw_digest, char **user_msg, char *userpass
 #ifdef USEMYSQL
-	, char *dbpass)
+	, char *dbpass) {
 #else
-	);
+	) {
 #endif
-{
 	char		string[AUTH_STRING_LEN];
 	char		name[AUTH_STRING_LEN];
 	VALUE_PAIR	*auth_type_pair;
@@ -403,8 +402,6 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
 				 */
 #ifdef USEMYSQL
 				strncpy(dbpass, password_pair->strvalue, 127);
-#else
-				*dbpass = '\0';
 #endif
 				if (password_pair == NULL ||
 				    strcmp(password_pair->strvalue, string)!=0)
@@ -691,7 +688,10 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 					MyAuthSock = NULL;
 				} else {
 					row = mysql_fetch_row(sqlresult);
-					used = atol(row[0]);
+					if (row[0] == NULL)
+						used = 0;
+					else
+						used = atol(row[0]);
 					mysql_free_result(sqlresult);
 				}
 				
@@ -890,8 +890,26 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			
 		}
 	}
+	/*       Check if the user is calling from the specified calling station id */
+	if (result >=0 && (check_item = pairfind(user_check, PW_CALLING_STATION_ID)) != NULL) {
 
+		VALUE_PAIR *req;
 
+		if ((req = pairfind(authreq->request, PW_CALLING_STATION_ID)) !=NULL) {
+
+			if (strcmp(req->strvalue,check_item->strvalue) != 0) {
+
+				sprintf(umsg, "\r\nYou cant login from number %s\r\n\n", req->strvalue);
+				user_msg = umsg;
+				result = -1;
+				rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+				log(L_ERR, "Unauthorized login attempt: [%s] (%s) (Attempted call from: %s)", namepair->strvalue, auth_name(authreq, 1), check_item->strvalue);
+			}
+		}
+	}
+  
+
+#ifdef USEMYSQL
 	if (result >=0 && (check_item = pairfind(user_check, PW_MAX_HOURS)) != NULL) {
 
 		MYSQL_ROW	row;
@@ -914,7 +932,10 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			MyAuthSock = NULL;
 		} else {
 			row = mysql_fetch_row(sqlresult);
-			used = atol(row[0]);
+			if (row[0] == NULL)
+				used = 0;
+			else
+				used = atol(row[0]);
 			mysql_free_result(sqlresult);
 		}
 		
@@ -945,6 +966,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		}
 
 	}
+#endif
 
 
 	if (result >= 0 &&
@@ -1175,10 +1197,12 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	authfree(authreq);
 	pairfree(user_check);
 	pairfree(user_reply);
+#ifdef USEMYSQL
 	if (!mysql_keepopen) {
 		mysql_close(MyAuthSock);
 		MyAuthSock = NULL;
 	}
+#endif
 
 	return 0;
 }
