@@ -10,29 +10,38 @@
 #
 # Returns:	0 = no duplicate, 1 = duplicate, >1 = error.
 #
-# Version:	@(#)checkrad.pl  1.16  12-May-1999  miquels@cistron.nl
+# Version:	@(#)checkrad.pl  1.18  25-Jul-1999  miquels@cistron.nl
 #
 #		livingston_snmp  1.1	Author: miquels@cistron.nl
 #		portslave_finger 1.0	Author: miquels@cistron.nl
 #		max40xx_finger	 1.0	Author: costa@mdi.ca
 #		computone_finger 1.1	Author: costa@mdi.ca
 #		sub tc_tccheck	 1.1	Author: alexisv@compass.com.ph
-#		pathras_telnet	 0.1	Author: accdias@sst.com.br
+#		pathras_telnet	 1.1	Author: accdias@sst.com.br
+#		patton_snmp	 1.0	Author: accdias@sst.com.br
+#		digitro_rusers	 1.0	Author: accdias@sst.com.br
 #		usrhiper_snmp    1.0    Author: igor@ipass.net
 #		multitech_snmp   1.0    Author: ehonzay@willmar.com
 #		netserver_telnet 1.0	Author: mts@interplanet.es
+#		versanet_snmp    1.0    Author: support@versanetcomm.com
 #
 #	Config: $debug is the file you want to put debug messages in
 #		$snmpget is the location of your ``snmpget'' program
 #		$naspass is the location of your NAS admin password file
 #
-#$debug   = '';
-$debug	 = '/var/log/checkrad.log';
 
-$snmpget = '/usr/bin/snmpget';
-$naspass = '/etc/raddb/naspasswd';
+$prefix		= "/usr/local";
+$localstatedir	= "/var";
+$logdir		= "${localstatedir}/log";
+$sysconfdir	= "/etc";
+$raddbdir	= "${sysconfdir}/raddb";
 
-$livingston_snmpread = "innercitesnmp";
+$debug		= "";
+#$debug		= "$logdir/checkrad.log";
+
+$snmpget	= "/usr/bin/snmpget";
+$naspass	= "$raddbdir/naspasswd";
+$rusers		= "/usr/bin/rusers";
 
 #
 #	PM3:	$lv_offs is where the last S port is before one or two
@@ -199,6 +208,29 @@ sub snmpget {
 	$ret;
 }
 
+#
+#	Strip domains, prefixes and suffixes from username
+#	
+#	Known prefixes: (P)PP, (S)LIP e (C)SLIP
+#	Known suffixes: .ppp, .slip e .cslip
+#
+#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
+#
+sub strip_username {
+	my ($user) = @_;
+	#
+	#	Trim white spaces.
+	#
+	$user =~ s/^\s*(.*?)\s*$/$1/;
+	#
+	#	Strip out domains, prefix and suffixes
+	#
+	$user =~ s/\@(.)*$//;
+	$user =~ s/^[PSC]//;
+	$user =~ s/\.(ppp|slip|cslip)$//;
+	$user;
+}
+
 #
 #	See if the user is logged in using the Livingston MIB.
 #	We don't check the username but the session ID.
@@ -211,7 +243,7 @@ sub livingston_snmp {
 	#	is greater than 29, substract 2 (S30 and S31 don't exist).
 	#	You might need to change this to 23 and 1 for the USA.
 	#
-	$_ = snmpget($ARGV[1], $livingston_snmpread, "$lvm.3.2.1.1.1.2.5");
+	$_ = snmpget($ARGV[1], "public", "$lvm.3.2.1.1.1.2.5");
 	/S([0-9]+)/;
 	$xport = $1 + 0;
 	$portidx = $ARGV[2] + (5 - $xport);
@@ -223,7 +255,7 @@ sub livingston_snmp {
 	#
 	#	Now get the session id from the terminal server.
 	#
-	$sessid = snmpget($ARGV[1], $livingston_snmpread, "$lvm.3.2.1.1.1.5.$portidx");
+	$sessid = snmpget($ARGV[1], "public", "$lvm.3.2.1.1.1.5.$portidx");
 
 	print LOG "  session id at port S$ARGV[2]: $sessid\n" if ($debug);
 
@@ -247,6 +279,7 @@ sub cisco_snmp {
 #
 #       Author: Eric Honzay of Bennett Office Products <ehonzay@willmar.com>
 #
+$msm    = '.iso.org.dod.internet.private.enterprises.995';
 sub multitech_snmp {
 	my $temp = $ARGV[2] + 1;
 
@@ -470,92 +503,162 @@ sub tc_tccheck {
 }
 
 #
-#	See if the user is already logged-in at the Cyclades PathRAS.
-#	(this routine by Antonio Dias <accdias@sst.com.br> based on
-#	tc_tccheck by Alexis C. Villalon <alexisv@compass.com.ph>).
-#	You must have the Net::Telnet module from CPAN for this to work.
-#	You must also have your /etc/raddb/naspasswd made up.
-#	Tested with PathRAS firmware 1.1.9g.
-# 
+#	Check a Cyclades PathRAS via telnet
+#
+#	Version: 1.1
+#
+#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
+#
 sub pathras_telnet {
-	#
-	#	Localize all variables first.
-	#
-	my ($ts, $terminalserver, $log, $login, $pass, $password);
-	my ($telnet, $curprompt, $curline, $ok);
-	my (@curlines, $user, $port);
+   #
+   #	Localize all variables first.
+   #
+   my (@users, $pathras, $port, $errmsg, $user, $login, $password);
+   #
+   #	Do we have Net::Telnet installed?
+   #
+   return 2 unless (check_net_telnet());
+   #
+   #	Get login name and password for NAS from $naspass file.
+   #
+   ($login, $password) = naspasswd($ARGV[1], 1);
+   #
+   #	NAS doesn't have a password defined
+   #
+   return 2 if ($password eq "");
+   #
+   #	Communicate with PathRAS using Net::Telnet, then access
+   #	menu option 6.8 to see who are logged in. This assumes 
+   #	you are using the default Prompt String (menu option 6.2)
+   #	and is based on PathRAS firmware version 1.1.9g
+   # 
+   #
+   $pathras = new Net::Telnet (
+   	Timeout => 10, 
+   	Prompt => '/(.*)\s:*$/', 
+   	Errmode => 'return'
+   );
+   #
+   #
+   #
+   if (!$pathras->open($ARGV[1])) {;
+      print LOG "  Error: " . $pathras->errmsg . "\n" if ($debug);
+      $pathras->close;
+      return 2;
+   }
+   #
+   #	Dunno why but PathRAS only issue its banner and 
+   #	the login prompt after receive a "CR" 
+   #
+   if (!$pathras->print("")) {
+      print LOG "  Error: " . $pathras->errmsg . "\n" if ($debug);
+      $pathras->close;
+      return 2;
 
-	return 2 unless (check_net_telnet());
+   }
+   #
+   #	Log on PathRAS
+   #
+   if (!($pathras->login($login, $password))) {
+      print LOG "  Error: " . $pathras->errmsg . "\n" if ($debug);
+      $pathras->close;
+      return 2;
+   }
+   #
+   #  Access menu option 6 "PathRAS Management"
+   #
+   if (!($pathras->cmd(String => '6', 
+   	Prompt => '/ ==\> $/', 
+   	Timeout => 10))) {
+      print LOG "  Error: " . $pathras->errmsg . "\n" if ($debug);
+      $pathras->close;
+      return 2;
+   }
+   #
+   #  Access menu option 8 "Show Active Ports"
+   #
+   if (!(@users = $pathras->cmd(String => '8', 
+   	Prompt => '/Type \<enter\>/', 
+   	Timeout => 10))) {
+      print LOG "  Error: " . $pathras->errmsg . "\n" if ($debug);
+      $pathras->close;
+      return 2;
+   }
+   #
+   # Since we got the info we want, let's close the session
+   #
+   $pathras->close;
+   #
+   #	Telnet closed.  We got the info so let's examine it.
+   #
+   foreach(@users) {
+      if (m/PPP Active|SLIP Active/) {
+         ($port, $user) = split;
+         #
+         # Strip out any prefixes and suffixes 
+         # from the username
+         #
+         $user = strip_username($user);
+         #
+         # Check if $user is already connected
+         #
+         if ($user eq $ARGV[3]) {
+            print LOG "  User $ARGV[3] found on " . 
+               "NAS $ARGV[1] port $port.\n" if ($debug);
+            return 1;
+         }
+      }
+   }
+   print LOG "  User $ARGV[3] not found on " .
+   	"NAS $ARGV[1].\n" if ($debug);
+   0;
+}
 
-	$terminalserver = $ARGV[1];
-	($login, $password) = naspasswd($terminalserver, 1);
-	return 2 if ($password eq "");
+#
+#	Check a Patton 2800 via snmp
+#
+#	Version: 1.0
+#
+#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
+#
+sub patton_snmp {
+   my($oid);
 
-	#
-	#	Communicate with PathRAS using Net::Telnet, then access
-	#	menu option 6.8 to see who are logged in. This assumes 
-	#	you are using the default Prompt String (menu option 6.2)
-	#	and is based on PathRAS firmware version 1.1.9g
-	# 
-	#
-	$telnet = new Net::Telnet (Timeout => 10);
-	$telnet->open($terminalserver);
-	#
-	#	Dunno why but PathRAS only issue its banner and 
-	#	the login prompt after receive a "CR" 
-	#
-	$telnet->print("");
-	#
-	#	Log on PathRAS
-	#
-	$telnet->waitfor('/login :.*$/');
-	$telnet->print($login);
-	$telnet->waitfor('/password :.*$/');
-	$telnet->print($password);
-	#
-	#	Wait for PathRAS default Prompt String "==> "
-	#	and access menu option 6.8 "Show Actives Ports"
-	#
-	$telnet->waitfor('/==\> .*$/');
-	$telnet->print("6");
-	$telnet->waitfor('/==\> .*$/');
-	$telnet->print("8");
+   $oid = '.1.3.6.1.4.1.1768.5.100.1.40.' . hex $ARGV[4];
+   #
+   # Check if the session still active
+   # 
+   if (snmpget($ARGV[1], "monitor", "$oid") == 0) {
+      print LOG "  Session $ARGV[4] still active on NAS " . 
+      	"$ARGV[1], port $ARGV[2], for user $ARGV[3].\n" if ($debug);
+      return 1;
+   }
+   0;
+}
 
-	while ($curprompt ne "==> ") {
-		($curline, $curprompt) = $telnet->waitfor
-			(String => "Type <enter> to return",
-			 String => "==> ",
-			 Timeout => 10);
-		$ok = $telnet->print("");
-		push @curlines, split(/^/m, $curline);
-	};
+#
+#      Check a Digitro BXS via rusers
+#
+#      Version: 1.0
+#
+#      Author: Antonio Dias of SST Internet <accdias@sst.com.br>
+#
+sub digitro_rusers {
+   if (-e $rusers && -x $rusers) {
+      open(FD, "$rusers $ARGV[1]|");
+   } else {
+      print LOG "   Error: can't execute $rusers\n" if $debug;
+      return 2;
+   }
 
-	$telnet->close;
-	#
-	#	Telnet closed.  We got the info.  Let's examine it.
-	#
-	foreach(@curlines) {
-		if (m/PPP Active|SLIP Active/) {
-			($port, $user) = split;
-			#
-			# Strip out any prefixes and suffixes 
-			# from the username
-			#
-			$user =~ s/^[PSC]//;
-			$user =~ s/\.(ppp|slip|cslip)$//;
-			#
-			# Check to see if $user is already connected
-			#
-			if ($user eq $ARGV[3]) {
-				print LOG "  $user matches $ARGV[3] " .
-					"on port $port" if ($debug);
-				return 1;
-			};
-		};
-	};
-	print LOG 
-	"  $ARGV[3] not found on PathRAS logged users list " if ($debug);
-	0;
+   while(<FD>) {
+      if (/$ARGV[3]/) {
+	close FD;
+	return 1;
+      }
+   }
+   close FD;
+   0;
 }
 
 #
@@ -657,6 +760,33 @@ sub usrnet_telnet {
 	0;
 }
 
+#
+#	Versanet's Perl Script Support:
+#
+#	___ versanet_snmp 1.0 by support@versanetcomm.com ___ July 1999
+#	Versanet Enterprise MIB Base: 1.3.6.1.4.1.2180
+#   
+#	VN2001/2002 use slot/port number to locate modems. To use snmp get we
+#	have to translate the original port number into a slot/port pair.
+#
+$vsm     = '.iso.org.dod.internet.private.enterprises.2180';
+sub versanet_snmp {
+        
+	print LOG "argv[2] = $ARGV[2] " if ($debug);
+	$port = $ARGV[2]%8;
+	$port = 8 if ($port eq 0);	  
+	print LOG "port = $port " if ($debug);
+	$slot = (($ARGV[2]-$port)/8)+1;
+	print LOG "slot = $slot" if ($debug);
+	$loginname = snmpget($ARGV[1], "public", "$vsm.27.1.1.3.$slot.$port");
+#
+#	Note: the "public" string above could be replaced by the public
+#	      community string defined in Versanet VN2001/VN2002.
+#
+	  print LOG "  user at slot $slot port $port: $loginname\n" if ($debug);	  ($loginname eq $ARGV[3]) ? 1 : 0;	
+}
+
+
 if ($debug) {
 	open(LOG, ">>$debug");
 	$now = localtime;
@@ -688,10 +818,16 @@ if ($ARGV[0] eq 'livingston') {
 	$ret = &tc_tccheck;
 } elsif ($ARGV[0] eq 'pathras') {
 	$ret = &pathras_telnet;
+} elsif ($ARGV[0] eq 'patton') {
+	$ret = &patton_snmp;
+} elsif ($ARGV[0] eq 'digitro') {
+	$ret = &digitro_rusers;
 } elsif ($ARGV[0] eq 'usrhiper') {
 	$ret = &usrhiper_snmp;
 } elsif ($ARGV[0] eq 'netserver') {
 	$ret = &usrnet_telnet;
+} elsif ($ARGV[0] eq 'versanet'){
+        $ret = &versanet_snmp;
 } elsif ($ARGV[0] eq 'other') {
 	$ret = 1;
 } else {
