@@ -265,6 +265,22 @@ void presuf_setup(VALUE_PAIR *request_pairs)
 
 #ifdef USEMYSQL
 
+		/*
+		 *	Find Prefix / Suffix.
+		 */
+		if ((presuf_pair = pairfind(request_pairs, PW_PREFIX)) == NULL &&
+		    (presuf_pair = pairfind(request_pairs, PW_SUFFIX)) == NULL)
+			return;
+		if (presufcmp(presuf_pair, name_pair->strvalue, name) != 0)
+			return;
+		/*
+		 *	See if username must be stripped.
+		 */
+		if ((tmp = pairfind(pl->check, PW_STRIP_USERNAME)) != NULL &&
+		    tmp->lvalue == 0)
+			return;
+		strcpy(name_pair->strvalue, name);
+		name_pair->length = strlen(name_pair->strvalue);
 
 #else
 	for (pl = users; pl; pl = pl->next) {
@@ -1038,6 +1054,10 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 #ifndef USEMYSQL
 	PAIR_LIST	*pl;
 #endif
+#ifdef NT_DOMAIN_HACK
+	char		*ptr;
+	char		newname[AUTH_STRING_LEN];
+#endif
 
 
 	/* 
@@ -1058,6 +1078,20 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 	 *	Find the entry for the user.
 	 */
 
+#ifdef NT_DOMAIN_HACK
+	/*
+	 *      Windows NT machines often authenticate themselves as
+	 *      NT_DOMAIN\username. Try to be smart about this.
+	 *
+	 *      FIXME: should we handle this as a REALM ?
+	 */
+	if ((ptr = strchr(name, '\\')) != NULL) {
+		strncpy(newname, ptr + 1, sizeof(newname));
+		newname[sizeof(newname) - 1] = 0;
+		strcpy(name, newname);
+	}
+#endif /* NT_DOMAIN_HACK */
+
 #ifdef USEMYSQL
 
 	if ((found = mysql_getvpdata(mysql_authcheck_table, &check_tmp, name, PW_VP_USERDATA)) <= 0)
@@ -1837,7 +1871,7 @@ void nas_free(NAS *cl)
 /*
  *	Free a REALM list.
  */
-static void realm_free(REALM *cl)
+void realm_free(REALM *cl)
 {
 	REALM *next;
 
@@ -2102,6 +2136,8 @@ int read_config_files()
 	sprintf(buffer, "%s/%s", radius_dir, RADIUS_HINTS);
 	hints      = file_read(buffer, 0);
 #ifdef USEMYSQL
+	if (mysql_read_realms(mysql_realm_table) < 0)
+		return -1;
 	if (mysql_read_naslist(mysql_nas_table) < 0)
 		return -1;
 	if (mysql_read_clients(mysql_nas_table) < 0)
@@ -2113,10 +2149,11 @@ int read_config_files()
 	sprintf(buffer, "%s/%s", radius_dir, RADIUS_NASLIST);
 	if (read_naslist_file(buffer) < 0)
 		return -1;
-#endif
+
 	sprintf(buffer, "%s/%s", radius_dir, RADIUS_REALMS);
 	if (read_realms_file(buffer) < 0)
 		return -1;
+#endif
 
 	if (cache_passwd) {
 		log(L_INFO, "HASH:  Reinitializing hash structures "
