@@ -312,11 +312,11 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
       } 
 
 	if (sqlrecord->AcctStatusTypeId == PW_STATUS_ALIVE) {
-		sprintf(querystr, "UPDATE %s SET Framed-IP-Address = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress= '%s'", mysql_acct_table, sqlrecord->FramedIPAddress, sqlrecord->AcctSessionId, sqlrecord->UserName, sqlrecord->NASIPAddress);
+		sprintf(querystr, "UPDATE %s SET FramedIPAddress = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress= '%s'", mysql_acct_table, sqlrecord->FramedIPAddress, sqlrecord->AcctSessionId, sqlrecord->UserName, sqlrecord->NASIPAddress);
 		if (sqltrace)
 			DEBUG(querystr);
 		if (mysql_query(MyAcctSock, (const char *) querystr) < 0)
-		log(L_ERR, "Acct: Couldn't update SQL accounting after NAS reboot - %s", mysql_error(MyAcctSock));
+		log(L_ERR, "Acct: Couldn't update SQL accounting for ALIVE packet - %s", mysql_error(MyAcctSock));
 
 		if (mysqlfile) {
 			fputs(querystr, mysqlfile);
@@ -734,8 +734,8 @@ static int mysql_check_ts(MYSQL_ROW row) {
 	/*
 	 *      Find NAS type.
 	 */
-	if ((nas = nas_find(ipstr2long(row[3]))) == NULL) {
-                log(L_ERR, "Accounting: unknown NAS [%s]", row[3]);
+	if ((nas = nas_find(ipstr2long(row[4]))) == NULL) {
+                log(L_ERR, "Accounting: unknown NAS [%s]", row[4]);
                 return -1;
         }
 
@@ -860,7 +860,7 @@ int mysql_check_multi(char *name, VALUE_PAIR *request, int maxsimul) {
 			if (mysql_check_ts(row) == 1) {
 				count++;
 
-				if (ipno && atoi(row[18]) == ipno)
+				if (ipno && atoi(row[19]) == ipno)
 					mpp = 2;   
 
 			} else {
