@@ -292,7 +292,7 @@ int proxy_send(AUTH_REQ *authreq, int activefd)
 	}
 
 	if ((client = client_find(realm->ipaddr)) == NULL) {
-		log(L_PROXY, "cannot find secret for server %s in clients file",
+		log(L_PROXY, "cannot find secret for server %s",
 			realm->server);
 		strcpy(namepair->strvalue, saved_username);
 		return 0;
