@@ -131,6 +131,7 @@ enum {
 typedef struct mysqlrec {
 	char                            AcctSessionId[SQLBIGREC];
         char                            UserName[SQLBIGREC];
+        char                            Realm[SQLBIGREC];
         char                            NASIPAddress[SQLLILREC];
         unsigned long                   NASPortId;
         char                            NASPortType[SQLBIGREC];
@@ -206,6 +207,7 @@ extern int		acct_port;
 
 #ifdef USEMYSQL
 NAS		*naslist;
+REALM		*realms;
 CLIENT		*clients;
 DICT_ATTR	*dictionary_attributes;
 DICT_VALUE	*dictionary_values;
@@ -295,6 +297,7 @@ void		pairmove(VALUE_PAIR **to, VALUE_PAIR **from);
 void		pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
 void		auth_type_fixup(VALUE_PAIR *check);
 void		debug_pair_list(PAIR_LIST *pl);
+void		realm_free(REALM *cl);
 void		nas_free(NAS *cl);
 void		clients_free(CLIENT *cl);
 void		user_gettime(char *valstr, struct tm *tm);
@@ -341,6 +344,8 @@ char mysql_authreply_table[MAX_TABLE_LEN];
 char mysql_groupcheck_table[MAX_TABLE_LEN];
 char mysql_groupreply_table[MAX_TABLE_LEN];
 char mysql_usergroup_table[MAX_TABLE_LEN];
+char mysql_realm_table[MAX_TABLE_LEN];
+char mysql_realmgroup_table[MAX_TABLE_LEN];
 char mysql_nas_table[MAX_TABLE_LEN];
 char mysql_dict_table[MAX_TABLE_LEN];
 int  mysql_keepopen;
@@ -350,9 +355,10 @@ MYSQL *MyAcctSock;
 MYSQL MyAuthConn;
 MYSQL MyAcctConn;
 int		mysql_start();
-int		mysql_save_acct(MYSQLREC sqlrecord);
-int		mysql_userparse(VALUE_PAIR **first_pair, MYSQL_ROW row, int mode);
+int		mysql_save_acct(MYSQLREC *sqlrecord);
+int		mysql_userparse(VALUE_PAIR **first_pair, MYSQL_ROW row);
 int		mysql_checksocket(const char *facility);
+int		mysql_read_realms(char *realmtable);
 int		mysql_getvpdata(char *table, VALUE_PAIR **vp, char *user, int mode);
 int		mysql_check_multi(char *name, VALUE_PAIR *request, int maxsimul);
 int		mysql_read_naslist(char *nastable);
